==> mplhep_data-0.0.3.tar.gz: mplhep_data-0.0.3/README.md <==
# mplhep_data
[![Actions Status][actions-badge]][actions-link]
[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]
[![Scikit-HEP][sk-badge]](https://scikit-hep.org/)

Sub-package to hold data (fonts) for [mplhep](https://github.com/scikit-hep/mplhep).

[actions-badge]:            https://github.com/Scikit-HEP/mplhep_data/workflows/CI/badge.svg
[actions-link]:             https://github.com/Scikit-HEP/mplhep_data/actions
[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/mplhep_data
[conda-link]:               https://github.com/conda-forge/mplhep_data-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/Scikit-HEP/mplhep_data/discussions
[gitter-badge]:             https://badges.gitter.im/https://github.com/Scikit-HEP/mplhep_data/community.svg
[gitter-link]:              https://gitter.im/https://github.com/Scikit-HEP/mplhep_data/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
[pypi-link]:                https://pypi.org/project/mplhep_data/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/mplhep_data
[pypi-version]:             https://badge.fury.io/py/mplhep_data.svg
[rtd-badge]:                https://readthedocs.org/projects/mplhep_data/badge/?version=latest
[rtd-link]:                 https://mplhep_data.readthedocs.io/en/latest/?badge=latest
[sk-badge]:                 https://scikit-hep.org/assets/images/Scikit--HEP-Project-blue.svg

## Fonts
Fonts distributed in this package have open licenses and can be redistributed. While it
would be preferable to download the files from their original repositories, there is no
convenient way to do that due to varying repo structures. The following fonts are
included:

#### Tex Gyre Heros
https://ctan.org/pkg/tex-gyre-heros?lang=en

#### Fira Sans
https://github.com/mozilla/Fira

#### Fira Math
https://github.com/firamath/firamath

==> mplhep_data-0.0.4.tar.gz: mplhep_data-0.0.4/README.md <==
# mplhep_data
[![Actions Status][actions-badge]][actions-link]
[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![Scikit-HEP][sk-badge]](https://scikit-hep.org/)

Sub-package to hold data (fonts) for [mplhep](https://github.com/scikit-hep/mplhep).

[actions-badge]:            https://github.com/Scikit-HEP/mplhep_data/workflows/CI/badge.svg
[actions-link]:             https://github.com/Scikit-HEP/mplhep_data/actions
[black-badge]:              https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]:               https://github.com/psf/black
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/mplhep_data
[conda-link]:               https://github.com/conda-forge/mplhep_data-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/Scikit-HEP/mplhep_data/discussions
[gitter-badge]:             https://badges.gitter.im/https://github.com/Scikit-HEP/mplhep_data/community.svg
[gitter-link]:              https://gitter.im/https://github.com/Scikit-HEP/mplhep_data/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge
[pypi-link]:                https://pypi.org/project/mplhep_data/
[pypi-version]:             https://badge.fury.io/py/mplhep_data.svg
[rtd-badge]:                https://readthedocs.org/projects/mplhep_data/badge/?version=latest
[rtd-link]:                 https://mplhep_data.readthedocs.io/en/latest/?badge=latest
[sk-badge]:                 https://scikit-hep.org/assets/images/Scikit--HEP-Project-blue.svg

## Fonts
Fonts distributed in this package have open licenses and can be redistributed. While it
would be preferable to download the files from their original repositories, there is no
convenient way to do that due to varying repo structures. The following fonts are
included:

#### Tex Gyre Heros
https://ctan.org/pkg/tex-gyre-heros

#### Tex Gyre Termes
https://ctan.org/pkg/tex-gyre-termes

#### Fira Sans
https://github.com/mozilla/Fira

#### Fira Math
https://github.com/firamath/firamath
